==> libakonadi-19.04.2-4-aarch64.pkg.tar.xz: usr/lib/cmake/KF5Akonadi/KF5AkonadiTargets-noconfig.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file.
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KF5::AkonadiPrivate" for configuration ""
set_property(TARGET KF5::AkonadiPrivate APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::AkonadiPrivate PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKF5AkonadiPrivate.so.5.11.2"
  IMPORTED_SONAME_NOCONFIG "libKF5AkonadiPrivate.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::AkonadiPrivate )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::AkonadiPrivate "${_IMPORT_PREFIX}/lib/libKF5AkonadiPrivate.so.5.11.2" )

# Import target "KF5::AkonadiCore" for configuration ""
set_property(TARGET KF5::AkonadiCore APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::AkonadiCore PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "Qt5::Network;Qt5::Widgets;KF5::AkonadiPrivate;KF5::DBusAddons;KF5::I18n;KF5::IconThemes;KF5::ConfigCore"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKF5AkonadiCore.so.5.11.2"
  IMPORTED_SONAME_NOCONFIG "libKF5AkonadiCore.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::AkonadiCore )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::AkonadiCore "${_IMPORT_PREFIX}/lib/libKF5AkonadiCore.so.5.11.2" )

# Import target "KF5::AkonadiAgentBase" for configuration ""
set_property(TARGET KF5::AkonadiAgentBase APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::AkonadiAgentBase PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::AkonadiPrivate;KF5::AkonadiWidgets;KF5::DBusAddons;KF5::I18n;Qt5::Network"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKF5AkonadiAgentBase.so.5.11.2"
  IMPORTED_SONAME_NOCONFIG "libKF5AkonadiAgentBase.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::AkonadiAgentBase )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::AkonadiAgentBase "${_IMPORT_PREFIX}/lib/libKF5AkonadiAgentBase.so.5.11.2" )

# Import target "KF5::AkonadiWidgets" for configuration ""
set_property(TARGET KF5::AkonadiWidgets APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::AkonadiWidgets PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::I18n;KF5::IconThemes;KF5::XmlGui;KF5::ItemViews;KF5::DBusAddons;Qt5::Sql;KF5::AkonadiPrivate;KF5::WindowSystem;KF5::Completion"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKF5AkonadiWidgets.so.5.11.2"
  IMPORTED_SONAME_NOCONFIG "libKF5AkonadiWidgets.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::AkonadiWidgets )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::AkonadiWidgets "${_IMPORT_PREFIX}/lib/libKF5AkonadiWidgets.so.5.11.2" )

# Import target "KF5::AkonadiXml" for configuration ""
set_property(TARGET KF5::AkonadiXml APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::AkonadiXml PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::I18n"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKF5AkonadiXml.so.5.11.2"
  IMPORTED_SONAME_NOCONFIG "libKF5AkonadiXml.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::AkonadiXml )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::AkonadiXml "${_IMPORT_PREFIX}/lib/libKF5AkonadiXml.so.5.11.2" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> libakonadi-19.12.1-1-aarch64.pkg.tar.xz: usr/lib/cmake/KF5Akonadi/KF5AkonadiTargets-noconfig.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file.
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KF5::AkonadiPrivate" for configuration ""
set_property(TARGET KF5::AkonadiPrivate APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::AkonadiPrivate PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKF5AkonadiPrivate.so.5.13.1"
  IMPORTED_SONAME_NOCONFIG "libKF5AkonadiPrivate.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::AkonadiPrivate )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::AkonadiPrivate "${_IMPORT_PREFIX}/lib/libKF5AkonadiPrivate.so.5.13.1" )

# Import target "KF5::AkonadiCore" for configuration ""
set_property(TARGET KF5::AkonadiCore APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::AkonadiCore PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "Qt5::Network;Qt5::Widgets;KF5::AkonadiPrivate;KF5::DBusAddons;KF5::I18n;KF5::IconThemes;KF5::ConfigCore"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKF5AkonadiCore.so.5.13.1"
  IMPORTED_SONAME_NOCONFIG "libKF5AkonadiCore.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::AkonadiCore )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::AkonadiCore "${_IMPORT_PREFIX}/lib/libKF5AkonadiCore.so.5.13.1" )

# Import target "KF5::AkonadiAgentBase" for configuration ""
set_property(TARGET KF5::AkonadiAgentBase APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::AkonadiAgentBase PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::AkonadiPrivate;KF5::AkonadiWidgets;KF5::DBusAddons;KF5::I18n;Qt5::Network;KAccounts"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKF5AkonadiAgentBase.so.5.13.1"
  IMPORTED_SONAME_NOCONFIG "libKF5AkonadiAgentBase.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::AkonadiAgentBase )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::AkonadiAgentBase "${_IMPORT_PREFIX}/lib/libKF5AkonadiAgentBase.so.5.13.1" )

# Import target "KF5::AkonadiWidgets" for configuration ""
set_property(TARGET KF5::AkonadiWidgets APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::AkonadiWidgets PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::I18n;KF5::IconThemes;KF5::XmlGui;KF5::ItemViews;KF5::DBusAddons;Qt5::Sql;KF5::AkonadiPrivate;KF5::WindowSystem;KF5::Completion"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKF5AkonadiWidgets.so.5.13.1"
  IMPORTED_SONAME_NOCONFIG "libKF5AkonadiWidgets.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::AkonadiWidgets )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::AkonadiWidgets "${_IMPORT_PREFIX}/lib/libKF5AkonadiWidgets.so.5.13.1" )

# Import target "KF5::AkonadiXml" for configuration ""
set_property(TARGET KF5::AkonadiXml APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::AkonadiXml PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::I18n"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKF5AkonadiXml.so.5.13.1"
  IMPORTED_SONAME_NOCONFIG "libKF5AkonadiXml.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::AkonadiXml )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::AkonadiXml "${_IMPORT_PREFIX}/lib/libKF5AkonadiXml.so.5.13.1" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
